==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/bg.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Федерално споделяне",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Искате ли да добавите отдалечено споделяне {name} от {owner}@{remote}?",
    "Remote share" : "Отдалечено споделяне",
    "Remote share password" : "Парола за отдалечено споделяне",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави отдалечено споделяне",
    "Copy" : "Копиране",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "Invalid Federated Cloud ID" : "Невалидно Федерално Cloud ID",
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "Couldn't establish a federated share." : "Неуспешно осъществяване на федерално споделяне",
    "Couldn't establish a federated share, maybe the password was wrong." : "Неуспешно осъществяване на федерално споделяне, можеби паролата е грепна.",
    "Not allowed to create a federated share with the same user" : "Не е позволено създаване на федерално споделяне със същият потребител",
    "File is already shared with %s" : "Файлът е вече споделен с %s",
    "Accept" : "Приемам",
    "Sharing" : "Споделяне",
    "Open documentation" : "Отвори документацията",
    "Allow users on this server to send shares to other servers" : "Позволи на потребители от този сървър да споделят папки  с други сървъри",
    "Allow users on this server to receive shares from other servers" : "Позволи на потребители на този сървър да получават споделени папки от други сървъри",
    "HTML Code:" : "HTML код:",
    "The mountpoint name contains invalid characters." : "Името на mountpoint-a съдържа невалидни символи.",
    "Not allowed to create a federated share with the owner." : "Не е позволено създаване на федерално споделяне със собственика.",
    "Invalid or untrusted SSL certificate" : "Невалиден или недоверен SSL сертификат",
    "Could not authenticate to remote share, password might be wrong" : "Неуспешно удостоверяване на отдалеченото споделяне, възможно е паролата да е грешна",
    "Storage not valid" : "Невалидно хранилище",
    "Couldn't add remote share" : "Неуспешно добавяне на отдалечена споделена директория.",
    "Sharing %s failed, because this item is already shared with %s" : "Неуспешно споделяне на %s, защото съдържанието е вече споделено с %s."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/bg.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Искате ли да добавите отдалечено споделяне {name} от {owner}@{remote}?",
    "Remote share" : "Отдалечено споделяне",
    "Remote share password" : "Парола за отдалечено споделяне",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави отдалечено споделяне",
    "Copy" : "Копиране",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "Invalid Federated Cloud ID" : "Невалиден Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "Couldn't establish a federated share." : "Неуспешно осъществяване на федерално споделяне",
    "Couldn't establish a federated share, maybe the password was wrong." : "Неуспешно осъществяване на федерално споделяне, можеби паролата е грепна.",
    "Not allowed to create a federated share with the same user" : "Не е позволено създаване на федерално споделяне със същият потребител",
    "File is already shared with %s" : "Файлът е вече споделен с %s",
    "Federated sharing" : "Федерално споделяне",
    "Accept" : "Приемам",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID - %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID",
    "Sharing" : "Споделяне",
    "Open documentation" : "Отвори документацията",
    "Allow users on this server to send shares to other servers" : "Позволи на потребители от този сървър да споделят папки  с други сървъри",
    "Allow users on this server to receive shares from other servers" : "Позволи на потребители на този сървър да получават споделени папки от други сървъри",
    "Your Federated Cloud ID:" : "Вашият Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Споделете, за да могат приятелите ви да споделят файлове, с вас:",
    "Add to your website" : "Добавете към вашия уеб сайт",
    "Share with me via Nextcloud" : "Споделете с мен, чрез Nextcloud",
    "HTML Code:" : "HTML код:",
    "Sharing %s failed, because this item is already shared with %s" : "Неуспешно споделяне на %s, защото съдържанието е вече споделено с %s."
},
"nplurals=2; plural=(n != 1);");
